@@ -45,7 +45,7 @@ set-up and tear down.
 import asyncio
 import functools
 import types
-import unittest.case
+import unittest
 import sys
 import warnings
 
@@ -116,7 +116,7 @@ class _Policy(asyncio.AbstractEventLoopPolicy):
             self.original_policy.set_child_watcher(None)
 
 
-class TestCase(unittest.case.TestCase):
+class TestCase(unittest.TestCase):
     """
     A test which is a coroutine function or which returns a coroutine will run
     on the loop.
@@ -433,6 +433,8 @@ class ClockedTestCase(TestCase):
     """
     Subclass of :class:`~asynctest.TestCase` with a controlled loop clock,
     useful for testing timer based behaviour without slowing test run time.
+
+    The clock will only advance when :meth:`advance()` is called.
     """
     def _init_loop(self):
         super()._init_loop()
